ewa.rules._template

Package ewa :: Module rules :: Class _template |
[hide private]
[frames] | no frames]

# Class _template

source code

         object --+
                  |
    string.Template --+
                      |
                     _template

Nested Classes | [hide private]
Inherited from `string.Template`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `string.Template`: `__init__`, `safe_substitute`, `substitute` Inherited from `string.Template` (private): `_invalid` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| idpattern = ``'``[_a-z0-9]+``'``
| pattern = `re.compile(r'`(?ix)`\$`(?:``(?P<``escaped``>`\$`)``|``(?P<``named``>``[`_a`...``
Inherited from `string.Template`: `delimiter`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### pattern Value:
      re.compile(r'(?ix)\$(?:(?P<escaped>\$)|(?P<named>[_a-z0-9]+)|\{(?P<bra
      ced>[_a-z0-9]+)\}|(?P<invalid>))')